==> knox-1.2.0-src.zip: knox-1.2.0/gateway-i18n/src/main/java/org/apache/knox/gateway/i18n/messages/loggers/test/TestMessageLogger.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.i18n.messages.loggers.test;

import org.apache.knox.gateway.i18n.messages.MessageLevel;
import org.apache.knox.gateway.i18n.messages.MessageLogger;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class TestMessageLogger implements MessageLogger {

  public final List<TestMessageRecord> records = Collections.synchronizedList( new ArrayList<TestMessageRecord>() );

  public final String name;

  TestMessageLogger( final String name ) {
    this.name = name;
  }

  public String getName() {
    return name;
  }

  @Override
  public boolean isLoggable( MessageLevel level ) {
    return true;
  }

  @Override
  public void log( final StackTraceElement caller, final MessageLevel level, final String id, final String text, final Throwable thrown ) {
    TestMessageRecord record = new TestMessageRecord( this, caller, level, id, text, thrown );
    records.add( record );
  }

}

==> knox-1.3.0-src.zip: knox-1.3.0/gateway-i18n/src/main/java/org/apache/knox/gateway/i18n/messages/loggers/test/TestMessageLogger.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.i18n.messages.loggers.test;

import org.apache.knox.gateway.i18n.messages.MessageLevel;
import org.apache.knox.gateway.i18n.messages.MessageLogger;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class TestMessageLogger implements MessageLogger {

  public final List<TestMessageRecord> records = Collections.synchronizedList(new ArrayList<>() );

  public final String name;

  TestMessageLogger( final String name ) {
    this.name = name;
  }

  public String getName() {
    return name;
  }

  @Override
  public boolean isLoggable( MessageLevel level ) {
    return true;
  }

  @Override
  public void log( final StackTraceElement caller, final MessageLevel level, final String id, final String text, final Throwable thrown ) {
    TestMessageRecord record = new TestMessageRecord( this, caller, level, id, text, thrown );
    records.add( record );
  }

}
